@@ -60,10 +60,7 @@
 #include "qps.h"
 #include "qpsapp.h"
 #include "dialogs.h"
-#include "commanddialog.h"
-#include "commandutils.h"
 #include "watchcond.h"
-#include "watchdogdialog.h"
 #include "lookup.h"
 #include "misc.h"
 
@@ -96,17 +93,12 @@
 #include <iostream>
 
 /* --------------------- Global Variable START ---------------------- */
-QList<Command *> commands;
-
 bool previous_flag_show_thread_prev = false; // previous state
 bool flag_show_thread = false; // to see informations at the thread level
-int flag_thread_ok = true;     // we presume a kernel 2.6.x using NPTL
+bool flag_thread_ok = true;     // we presume a kernel 2.6.x using NPTL
 bool flag_start_mini = false; // Need for Xorg.Session
 bool flag_refresh = true;     // DEL
-bool flag_xcompmgr = false;   // DEL test.compiz..
-bool flag_devel = false;
 bool flag_schedstat = false;
-bool flag_smallscreen = false;
 bool flag_firstRun = true; // test
 
 Qps *qps;
@@ -114,9 +106,6 @@ Qps *qps;
 SearchBox *search_box = nullptr;
 TFrame *infobox = nullptr; // testing
 QFontComboBox *font_cb = nullptr;
-WatchdogDialog *watchdogDialog = nullptr;
-
-/// PDisplay *pdisplay;
 
 QList<Procview *> proclist;
 
@@ -172,26 +161,14 @@ Qps::Qps()
     timer_id = 0;
     field_win = nullptr;
     prefs_win = nullptr;
-    command_win = nullptr;
     default_icon = nullptr;
     default_icon_set = false;
+    explicit_quit = false;
+    under_wayland = QGuiApplication::platformName() == "wayland";
 
     setIconSize(24, 24); // Important!!
                          //	setMouseTracking(true); // no need?
 
-    if (flag_devel)
-    {
-        thread_main = thread(); // Test
-        std::cout << "qps thread = " << thread() << " qApp thread = "
-            << QApplication::instance()->thread() << std::endl;
-    }
-
-    // watchdogDialog = new WatchdogDialog; //Memory Leak
-
-    //	font_cb=new QFontComboBox(this); // preload
-    //	font_cb->setWritingSystem ( QFontDatabase::Latin );
-    // font_cb->hide();
-
     make_signal_popup_menu();
 
     // MOVETO Pstable !!
@@ -200,7 +177,7 @@ Qps::Qps()
     m_fields = new QMenu( tr( "Add Field" ), this);
     m_headpopup->addMenu(m_fields);
 
-    m_command = new QMenu( tr( "Command" ), this); // filled in later
+    m_session = new QMenu( tr( "Session" ), this);
 
     QAction *act;
 
@@ -247,11 +224,6 @@ Qps::Qps()
             &Qps::view_menu);
     connect(m_field, &QMenu::aboutToShow, this, &Qps::update_menu_status);
 
-    /// connect(m_view, SIGNAL(triggered(QAction *)),this,
-    /// SLOT(view_menu(QAction
-    /// *)));
-    /// connect(m_view, SIGNAL(aboutToShow ()), SLOT(update_menu_status()));
-
     m_options = new QMenu( tr( "Options" ), this);
     m_options->addAction( tr( "Update Period..." ), this, &Qps::menu_update);
     m_options->addSeparator();
@@ -278,21 +250,17 @@ Qps::Qps()
     connect(m_options, &QMenu::aboutToShow, this, &Qps::update_menu_status);
 
     QMenu *m_help = new QMenu( tr( "Help" ), this);
-    // m_help->addAction("FAQ", this, SLOT(license()));
     m_help->addAction(QIcon::fromTheme("help-about"),  tr( "About" ), this,
                       &Qps::about);
 
-    // menu = new QMenuBar(this);
     menubar = new QMenuBar;
-    menubar->addMenu(m_command);
-    // am_view=menubar->addMenu(m_view);
+    menubar->addMenu(m_session);
     menubar->addMenu(m_field);
     menubar->addMenu(m_options);
     menubar->addSeparator();
     menubar->addMenu(m_help);
 
     ctrlbar = new ControlBar(this);
-    // controlbar=ctrlbar;
 
     connect(ctrlbar, &ControlBar::need_refresh, this, &Qps::refresh);
     connect(ctrlbar, &ControlBar::viewChange, this,
@@ -301,16 +269,10 @@ Qps::Qps()
     context_col = -1;
 
     procview = new Procview(); // refresh() only not rebuild()
-/// procview = new Procview("localhost"); // refresh() only not rebuild()
-/// procview->refresh(); // TODO
-/// proclist.append(procview);
-/// procview->start(); // thread start
 
     pstable = new Pstable(this, procview); // no refresh()
     PDisplay *display = new PDisplay(this);
     infobar = display->addSystem(procview);
-    //.	infobar = new Infobar(this,procview); // graph_bar
-    //	infobar = new Infobar(procview); // graph_bar
     statusBar = new StatusBar(this);
 
     if (!read_settings())
@@ -324,7 +286,12 @@ Qps::Qps()
     pstable->setReveseSort(procview->reversed);
 
     set_table_mode(procview->treeview); //  Pstable::refresh() occur
-    make_command_menu();                // after qpsrc reading
+
+    m_session->addAction(QIcon::fromTheme(QStringLiteral("application-exit"))
+                        , tr( "Quit" )
+                        , this
+                        , &Qps::save_quit
+                        , Qt::ALT | Qt::Key_Q);
 
     // misc. accelerators
     (void) new QShortcut(Qt::CTRL + Qt::Key_Q, this, SLOT(save_quit()));
@@ -332,19 +299,14 @@ Qps::Qps()
                                   ctrlbar->pauseButton, SLOT(click()));
     (void) new QShortcut(Qt::CTRL + Qt::Key_L, pstable, SLOT(repaintAll()));
 
-    // MOVETO : pstable better? hmmm...
-    // where is leftClick?
     connect(pstable, &HeadedTable::doubleClicked, this, &Qps::open_details );
     connect(pstable, &HeadedTable::rightClicked, this,
             &Qps::show_popup_menu);
     connect(pstable->header(), &TableHead::rightClicked, this,
             &Qps::context_heading_menu);
-    //	connect(netable, SIGNAL(rightClicked(QPoint)), this,
-    // SLOT(context_row_menu(QPoint)));
 
     selection_items_enabled = true; // ????
     update_load_time = 0;
-    //// update_menu_status();
 
     QVBoxLayout *vlayout = new QVBoxLayout;
     vlayout->setMargin(0);
@@ -353,57 +315,23 @@ Qps::Qps()
     else
         vlayout->setSpacing(1);
 
-    // vlayout->addWidget(menu);
     vlayout->setMenuBar(menubar);
     vlayout->addWidget(display);
-    // vlayout->addWidget( infobar);
     vlayout->addWidget(ctrlbar);
 
-    /// vlayout->addSpacing(5);
-
-    // if(flag_devel){
-    if (false)
-    {
-        if (false)
-        {
-            QSplitter *splitter = new QSplitter(Qt::Vertical);
-            QDockWidget *dock = new QDockWidget(tr("Detail"), this);
-            dock->setFeatures(QDockWidget::DockWidgetClosable);
-            // dock->setWidget();
-            // dock->setAllowedAreas(Qt::LeftDockWidgetArea |
-            // Qt::RightDockWidgetArea);
-            // customerList = new QListWidget(dock);
-            // vlayout->addStretch();
-            splitter->addWidget(pstable);
-            splitter->addWidget(dock);
-            vlayout->addWidget(splitter);
-            vlayout->addWidget(statusBar);
-            setLayout(vlayout);
-        }
-    }
-
     logbox = new QTextEdit(this);
     logbox->setReadOnly(true);
 
-    if (false) // if(flag_smallscreen==false)
-    {
-        //
-    }
-    else
-    {
-        vlayout->addWidget(pstable);
-        vlayout->addWidget(logbox);
-        logbox->hide();
-    }
+    vlayout->addWidget(pstable);
+    vlayout->addWidget(logbox);
+    logbox->hide();
 
     vlayout->addWidget(statusBar);
     setLayout(vlayout);
 
     infobox = new TFrame(this);
-    //	setAttribute(Qt::WA_ShowWithoutActivating);
     if (update_period != eternity)
         Qps::update_timer(); // startTimer(update_period);
-    ///	setFocusPolicy (Qt::WheelFocus);
 
     bar_visibility(); // need
 
@@ -566,7 +494,7 @@ void Qps::bar_visibility()
 }
 
 void Qps::timerEvent(QTimerEvent */*e*/) { Qps::refresh(); }
-//
+
 // dialogs.cpp:    qps->update_timer();
 void Qps::update_timer()
 {
@@ -638,18 +566,6 @@ void Qps::resizeEvent(QResizeEvent *e)
     {
         search_box->hide();
     }
-
-    return;
-    if (e->size().width() < 639)
-    {
-        flag_smallscreen = true;
-        statusBar->hide();
-    }
-    else
-    {
-        flag_smallscreen = false;
-        statusBar->show();
-    }
 }
 
 /*
@@ -664,28 +580,27 @@ void Qps::closeEvent(QCloseEvent *e)
     winPos.setX(geometry().x());
     winPos.setY(geometry().y());
 
-    if ((Qps::flag_exit == false) && trayicon->hasSysTray)
+    if (!explicit_quit && !Qps::flag_exit && trayicon->hasSysTray)
     {
         e->ignore(); // dont close window!
         hide();
         return;
     }
     e->accept();
-    save_quit();
+    if (!explicit_quit) // call save_quit() only if not called by it
+        save_quit();
 }
 
-// call by void Qps::make_command_menu()
-//			void signal_handler(int sig)
-void Qps::save_quit() // will be removed !
+void Qps::save_quit()
 {
-    close(); // if another window exists, then no exit. // occurs
-             // QCoseEvent!
+    explicit_quit = true;
+    close();
     save_settings();
-    qApp->quit(); // MACRO
+    qApp->quit();
 }
 
 // NEW Version !
-// : write geometry, visible fields and other settings to $HOME/.qpsrc
+// : write geometry, visible fields and other settings
 void Qps::save_settings()
 {
     if (Qps::auto_save_options)
@@ -887,7 +802,8 @@ void Qps::menu_custom()
     if (field_win)
     {
         field_win->show();
-        field_win->raise();
+        if (!under_wayland)
+            field_win->raise();
     }
     else
     {
@@ -900,10 +816,6 @@ void Qps::menu_custom()
     }
 }
 
-// MOVE TO PSTABlE ? hmmm wait...
-// Interface for  reading_setting()
-// SLOT:
-//
 // called by
 // 	1.click Tree_checkbox
 //	2.void Qps::view_menu(int id)
@@ -967,90 +879,6 @@ void Qps::field_removed(int index)
     context_col = -1;
 }
 
-// moveto command?
-void Qps::menu_edit_cmd()
-{
-    if (command_win)
-    {
-        command_win->show();
-        command_win->raise();
-    }
-    else
-    {
-        command_win = new CommandDialog();
-        command_win->show();
-        connect(command_win, &CommandDialog::command_change, this,
-                &Qps::make_command_menu);
-    }
-}
-
-// init command menu
-// callback by CommandDialog::add_new()
-void Qps::make_command_menu()
-{
-    // should clear SIGNAL!!!
-    QAction *act;
-    m_command->clear();
-    m_command->disconnect();
-
-    if (flag_devel)
-    {
-        m_command->addAction( tr( "WatchDog" ), watchdogDialog,
-                             &QWidget::show);
-        act = m_command->addAction( tr( "Edit Commands..." ), this,
-                                   &Qps::menu_edit_cmd);
-    }
-
-    add_default_command();
-
-    for (int i = 0; i < commands.size(); i++)
-    {
-        act = m_command->addAction(commands[i]->name);
-    }
-    connect(m_command, &QMenu::triggered, this,
-            &Qps::run_command);
-    //#ifdef SOLARIS
-    /* Solaris CDE don't have a tray, so we need a method to terminate */
-    m_command->addSeparator();
-    m_command->addAction(QIcon::fromTheme(QStringLiteral("application-exit"))
-                        , tr( "Quit" )
-                        , this
-                        , &Qps::save_quit
-                        , Qt::ALT + Qt::Key_Q);
-    //#endif
-}
-
-// run by MENU_ID ? qt slot?
-// void Qps::run_command(int command_id)
-void Qps::run_command(QAction *act)
-{
-    int i, idx = -1;
-    // FUNC_START
-
-    AddLog(act->text());
-
-    // find_command
-    for (i = 0; i < commands.size(); i++)
-    {
-        if (commands[i]->name == act->text())
-        {
-            if (commands[idx]->IsNeedProc() == false)
-            {
-                commands[idx]->call(nullptr);
-                return;
-            }
-
-            for (int i = 0; i < procview->linear_procs.size(); i++)
-            {
-                Procinfo *p = procview->linear_procs[i];
-                if (p->selected)
-                    commands[idx]->call(p);
-            }
-            break;
-        }
-    }
-}
-
 // detail
 void Qps::Action_Detail()
 {
@@ -1251,7 +1079,6 @@ void Qps::menu_update()
         txt = QString::asprintf("%d ms", update_period);
     IntervalDialog id(txt.toUtf8().data(), update_period != eternity);
     id.exec();
-    /// save_settings();
     return;
 }
 
@@ -1289,13 +1116,15 @@ void Qps::menu_prefs()
     if (prefs_win)
     {
         prefs_win->show();
-        prefs_win->raise();
+        if (!under_wayland)
+            prefs_win->raise();
     }
     else
     {
         prefs_win = new Preferences(this);
         prefs_win->show();
-        prefs_win->raise();
+        if (!under_wayland)
+            prefs_win->raise();
 
         connect(prefs_win, &Preferences::prefs_change, this, &Qps::config_change);
     }
@@ -1549,12 +1378,11 @@ static Sflagvar flagvars[] = {{"ExitOnClose", &Qps::flag_exit},
                               {"SavePos", &Qps::save_pos},
                               {"TabView", &Qps::flag_useTabView},
                               {"SingleCPU", &Procview::flag_pcpu_single},
-                              {"devel", &flag_devel},
                               {"cmdpath", &Procview::flag_show_file_path},
                               {"infobar", &Qps::show_infobar},
                               {"ctrlbar", &Qps::show_ctrlbar},
                               {"statbar", &Qps::show_statusbar},
-                              {"autosave", &Qps::auto_save_options},
+                              //{"autosave", &Qps::auto_save_options}, // Always ave settings
                               {"cpubar", &Qps::show_cpu_bar},
                               {"loadgraph", &Qps::show_load_graph},
                               {"loadicon", &Qps::load_in_icon},
@@ -1652,25 +1480,6 @@ bool Qps::read_settings()
     procview->viewproc = i;
     ctrlbar->view->setCurrentIndex(i); // procview->viewproc=set.value("viewproc").toInt();
 
-    int size = set.beginReadArray("watchdog");
-    for (int i = 0; i < size; i++)
-    {
-        set.setArrayIndex(i);
-        watchCond *w = new watchCond;
-        w->putstring(set.value("cat").toString());
-        watchlist.append(w);
-    }
-    set.endArray();
-    size = set.beginReadArray("commands");
-    for (int i = 0; i < size; i++)
-    {
-        set.setArrayIndex(i);
-        Command *c = new Command;
-        c->putString(set.value("cmd").toString());
-        commands.append(c);
-    }
-    set.endArray();
-
     return true;
 }
 
@@ -1685,15 +1494,18 @@ void Qps::write_settings() // save setting
     set.beginGroup("geometry");
     set.setValue("width", geometry().width());
     set.setValue("height", geometry().height());
-    if (isVisible())
+    if (!under_wayland)
     {
-        set.setValue("x", geometry().x());
-        set.setValue("y", geometry().y());
-    }
-    else
-    {
-        set.setValue("x", winPos.x());
-        set.setValue("y", winPos.y());
+        if (isVisible())
+        {
+            set.setValue("x", geometry().x());
+            set.setValue("y", geometry().y());
+        }
+        else
+        {
+            set.setValue("x", winPos.x());
+            set.setValue("y", winPos.y());
+        }
     }
     set.endGroup();
 
@@ -1723,22 +1535,6 @@ void Qps::write_settings() // save setting
     set.setValue("font", QApplication::font().toString());
 
     set.setValue("interval", update_period);
-
-    set.beginWriteArray("watchdog");
-    for (int i = 0; i < watchlist.size(); i++)
-    {
-        set.setArrayIndex(i);
-        set.setValue("cat", watchlist[i]->getstring());
-    }
-    set.endArray();
-
-    set.beginWriteArray("commands");
-    for (int i = 0; i < commands.size(); i++)
-    {
-        set.setArrayIndex(i);
-        set.setValue("cmd", commands[i]->getString());
-    }
-    set.endArray();
 }
 
 // return host name with domain stripped
@@ -1821,7 +1617,6 @@ int main(int argc, char **argv, char **envp)
             flag_start_mini = true;
         }
     }
-    //	codec = QTextCodec::codecForLocale(); // for Local locale
     check_system_requirement(); // check kernel version.. etc in proc.cpp
 
     QpsApp app(argc, argv);
@@ -1841,7 +1636,6 @@ int main(int argc, char **argv, char **envp)
 
     // MOVETO  Systray
     QMenu *menu = new QMenu(qps);
-    /// menu->addAction( UniString("About"), qps, SLOT(about()) );
     menu->addAction( QObject::tr( "Show" )
                    , qps
                    , &Qps::showWindow);
@@ -1849,10 +1643,10 @@ int main(int argc, char **argv, char **envp)
                    , qps
                    , &Qps::hide);
     menu->addSeparator();
-    menu->addAction( QObject::tr( "Quit" )
+    menu->addAction( QIcon::fromTheme(QStringLiteral("application-exit"))
+                   , QObject::tr( "Quit" )
                    , qps
-                   , &Qps::save_quit
-                   , Qt::ALT + Qt::Key_Q);
+                   , &Qps::save_quit);
 
     trayicon = new TrayIcon(QPixmap((const char **)icon_xpm /* init icon */),
                             "qps", menu);
@@ -1951,55 +1745,6 @@ void Qps::about()
     diag->exec();
 }
 
-void Qps::license() // -> help()
-{
-
-    QDialog *diag = new QDialog(this);
-    diag->setWindowTitle("Quick Help");
-    // diag->setSizeGripEnabled(true) ;
-    QHBoxLayout *lay = new QHBoxLayout(diag);
-
-    QTextBrowser *browser = new QTextBrowser(diag);
-    browser->setMinimumSize(400, 200);
-
-    lay->addWidget(browser);
-
-    browser->setOpenExternalLinks(true);
-    browser->setOpenLinks(true);
-    browser->setText( tr( "<H1>QPS Help</H1>"
-                          "Updated: May 24 2005<BR>"
-                          "<A "
-                          "HREF=\"http://kldp.net/projects/qps\">http://kldp.net/projects/"
-                          "qps</"
-                          "A><HR>"
-
-                          "<table style=\"text-align: center; width: 100%;\" border=\"1\""
-                          " cellpadding=\"1\" cellspacing=\"0\">"
-                          "  <tbody>"
-                          "    <tr>"
-                          "      <td"
-                          " style=\"vertical-align: top; background-color: rgb(204, 204, "
-                          "204);\">Quit"
-                          "      </td>"
-                          "      <td >&nbsp; CTRL + q , CTRL + x"
-                          "      </td>"
-                          "    </tr>"
-                          "    <tr>"
-                          "      <td"
-                          " style=\"vertical-align: top; background-color: rgb(204, 204, "
-                          "204);\">Update"
-                          "      </td>"
-                          "      <td>&nbsp;Space , Enter "
-                          "      </td>"
-                          "    </tr>"
-                          "    <tr><td> process Terminate </td>  <td> ALT + T , DELETE </td> "
-                          "</tr>"
-                          "    <tr><td> process Kill </td>  <td> ALT + K  </td> </tr>"
-                          "  </tbody>"
-                          "</table>" ) );
-    diag->exec();
-}
-
 void SearchBox::keyPressEvent(QKeyEvent *e)
 {
     if (e->key() == Qt::Key_Delete)
